[libcroco] Typo fix s/occured/occurred/



commit 7c250a98646585ade34adfd853a933e7ebc01238
Author: Mattia Rizzolo <mattia debian org>
Date:   Tue Jan 3 10:17:22 2017 +0100

    Typo fix s/occured/occurred/
    
    https://bugzilla.gnome.org/show_bug.cgi?id=776798

 src/cr-input.c     |    6 +++---
 src/cr-parser.c    |    2 +-
 src/cr-prop-list.c |    2 +-
 src/cr-sel-eng.c   |    2 +-
 src/cr-tknzr.c     |    2 +-
 5 files changed, 7 insertions(+), 7 deletions(-)
---
diff --git a/src/cr-parser.c b/src/cr-parser.c
index a17f161..18c9a01 100644
--- a/src/cr-parser.c
+++ b/src/cr-parser.c
@@ -2745,7 +2745,7 @@ cr_parser_parse_stylesheet (CRParser * a_this)
  *coming the input stream given in parameter.
  *
  *Returns the newly created instance of #CRParser,
- *or NULL if an error occured.
+ *or NULL if an error occurred.
  */
 CRParser *
 cr_parser_new (CRTknzr * a_tknzr)
diff --git a/src/cr-prop-list.c b/src/cr-prop-list.c
index 0ce57fa..70a04f3 100644
--- a/src/cr-prop-list.c
+++ b/src/cr-prop-list.c
@@ -71,7 +71,7 @@ cr_prop_list_allocate (void)
  *Appends a property list to the current one.
  *
  *Returns the resulting prop list, or NULL if an error
- *occured
+ *occurred
  */
 CRPropList *
 cr_prop_list_append (CRPropList * a_this, CRPropList * a_to_append)
diff --git a/src/cr-sel-eng.c b/src/cr-sel-eng.c
index 3cd7241..4b92cbb 100644
--- a/src/cr-sel-eng.c
+++ b/src/cr-sel-eng.c
@@ -813,7 +813,7 @@ sel_matches_node_real (CRSelEng * a_this, CRSimpleSel * a_sel,
  *case, *a_len is set to the actual number of ruleset found.
  *@return CR_BAD_PARAM_ERROR in case any of the given parameter are
  *bad (e.g null pointer).
- *@return CR_ERROR if any other error occured.
+ *@return CR_ERROR if any other error occurred.
  */
 static enum CRStatus
 cr_sel_eng_get_matched_rulesets_real (CRSelEng * a_this,
diff --git a/src/cr-tknzr.c b/src/cr-tknzr.c
index ca9316e..e3af0ee 100644
--- a/src/cr-tknzr.c
+++ b/src/cr-tknzr.c
@@ -524,7 +524,7 @@ cr_tknzr_parse_comment (CRTknzr * a_this,
  *Error code can be either CR_PARSING_ERROR if the string 
  *parsed just doesn't
  *respect the production or another error if a 
- *lower level error occured.
+ *lower level error occurred.
  */
 static enum CRStatus
 cr_tknzr_parse_unicode_escape (CRTknzr * a_this, 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/cr-input.c b/src/cr-input.c
index 732068a..49000b1 100644
--- a/src/cr-input.c
+++ b/src/cr-input.c
@@ -231,8 +231,8 @@ cr_input_new_from_uri (const gchar * a_file_uri, enum CREncoding a_enc)
                                 /*we reached eof */
                                 loop = FALSE;
                         } else {
-                                /*a pb occured !! */
-                                cr_utils_trace_debug ("an io error occured");
+                                /*a pb occurred !! */
+                                cr_utils_trace_debug ("an io error occurred");
                                 status = CR_ERROR;
                                 goto cleanup;
                         }
@@ -874,7 +874,7 @@ cr_input_peek_byte2 (CRInput const * a_this, gulong a_offset, gboolean * a_eof)
  *Gets the memory address of the byte located at a given offset
  *in the input stream.
  *
  *Returns the address, otherwise NULL if an error occured.
  */
 guchar *
 cr_input_get_byte_addr (CRInput * a_this, gulong a_offset)
@@ -874,7 +874,7 @@ cr_input_peek_byte2 (CRInput const * a_this, gulong a_offset, gboolean * a_eof)
  *in the input stream.
  *
- *Returns the address, otherwise NULL if an error occured.
+ *Returns the address, otherwise NULL if an error occurred.
  */
 guchar *